========
GeoTrees
========

.. GeoTrees documentation master file, created by
   sphinx-quickstart on Fri Jul  5 11:49:36 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   introduction
   installation
   bisection
   record
   shape
   quadtree
   octtree
   kdtree
   users_guide

.. include:: hyperlinks.rst

..
.. Indices and tables
.. ------------------
..
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
